@@ -19,8 +19,10 @@
 #
 ##############################################################################
 
-from record import Record
-from .fields import *
+from .exception import RetrofixException
+from .fields import (Const, Char, Number, Date, Account, Numeric, Integer,
+    Selection)
+from .record import Record
 
 ORDERING_HEADER_RECORD = (
     (1, 2, 'record_code', Const('03')),
@@ -278,7 +280,7 @@ def read(data):
         elif Record.valid(current_line, ORDERING_FOOTER_RECORD):
             record = Record.extract(current_line, ORDERING_FOOTER_RECORD)
         else:
-            raise BaseException('Invalid record: "%s"' % current_line)
+            raise RetrofixException('Invalid record: "%s"' % current_line)
         records.append(record)
         current_line = lines.pop(0)
     return records
